package edu.cmu.cs.able.probes.RemosProbe;

import java.io.*;
import java.net.*;
import java.util.*;
import java.text.*;

/**
 * Maintain the ID stuff for remos probe. The ID is simply string combination of
 * of the IP address of the host, where the probe is created, and the time
 * stamp of the creation of this probe.
 */
public class ProbeID {
	/** ID is composed by "ip" and "date", 
	  * "address" is just used for sure
	  */
        InetAddress address; 
	/** IP address of the host where the probe is created */
	String ip;
	/** The time that the probe is created */
	String time;

	/**
	 * Construct a new ID using the give address
	 * @param addr the address of the host where the probe is running
	 */
	ProbeID(InetAddress addr) {
	    address = addr;
	    ip = address.getHostAddress();
	    // this.date = date.toString();
	    this.time = Long.toString(System.currentTimeMillis());
	}

	/**
	 * Create ProbeID object based on an ID string. That is, abstract the
	 * the ip, time, address fields from the ID string.
	 * @param strID the ID string
	 */
	ProbeID(String strID) {
	    int i = strID.indexOf('|');

	    ip = strID.substring(0,i);
	    time = strID.substring(i+1);

	    try {
	    	address = InetAddress.getByName(ip);
	    	// date = new SimpleDateFormat(strDate);
	    } catch (UnknownHostException ex) {
		System.err.println(ex.toString());
	    }
	}

	/**
	 * Transform the ProbeID into a string format, i.e., the ID string.
	 * ID string is used for the convenience of siena transmission.
	 * @return the ID string.
	 */
	public String toString() {
	    return ip + '|' + time.toString();
	}
}

